@@ -37,8 +37,8 @@ public:
     }
 
 public:
-    Ui::EventOrTodoDesktop *mUi;
-    int mOrigPercentCompleted;
+    Ui::EventOrTodoDesktop *mUi = nullptr;
+    int mOrigPercentCompleted = -1;
 
 public: // slots
     void sliderValueChanged(int);
@@ -67,14 +67,11 @@ IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop
     d->mUi->mCompletionPriorityWidget->hide();
     d->mUi->mTaskLabel->hide();
     const QFontMetrics metrics(d->mUi->mCompletedLabel->font());
-    d->mUi->mCompletedLabel->setMinimumWidth(metrics.width(QStringLiteral("100%")));
+    d->mUi->mCompletedLabel->setMinimumWidth(metrics.boundingRect(QStringLiteral("100%")).width());
     d->mUi->mTaskSeparator->hide();
 
-    connect(d->mUi->mCompletionSlider, SIGNAL(valueChanged(int)), SLOT(sliderValueChanged(int)));
-    connect(d->mUi->mPriorityCombo,
-            static_cast<void (KComboBox::*)(
-                            int)>(&KComboBox::currentIndexChanged), this,
-            &IncidenceCompletionPriority::checkDirtyStatus);
+    connect(d->mUi->mCompletionSlider, QOverload<int>::of(&QSlider::valueChanged), this, [this](int val) { d->sliderValueChanged(val);});
+    connect(d->mUi->mPriorityCombo, QOverload< int>::of(&KComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
 }
 
 IncidenceCompletionPriority::~IncidenceCompletionPriority()
