@@ -20,25 +20,24 @@
 #ifndef INCIDENCEEDITOR_OPENCOMPOSERJOB_H
 #define INCIDENCEEDITOR_OPENCOMPOSERJOB_H
 
+#include <KMime/Message>
+
 #include <KIdentityManagement/Identity>
-#include <kmime/kmime_message.h>
-
 #include <KJob>
-namespace IncidenceEditorNG
-{
 
+namespace IncidenceEditorNG {
 // Opens a Composer with a mail with one attachment (costructed my ITIPHandler)
 class OpenComposerJob : public KJob
 {
     Q_OBJECT
 
 public:
-    explicit OpenComposerJob(QObject *parent,
-                             const QString &to, const QString &cc, const QString &bcc,
-                             const KMime::Message::Ptr &message, const KIdentityManagement::Identity &identity);
-    virtual ~OpenComposerJob();
+    explicit OpenComposerJob(QObject *parent, const QString &to, const QString &cc,
+                             const QString &bcc, const KMime::Message::Ptr &message,
+                             const KIdentityManagement::Identity &identity);
+    ~OpenComposerJob() override;
 
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 private:
     void slotServiceOwnerChanged(const QString &, const QString &, const QString &);
@@ -51,6 +50,5 @@ private:
     KIdentityManagement::Identity mIdentity;
     bool mSuccess;
 };
-
 }
 #endif
