@@ -45,22 +45,8 @@ ResourceModel::ResourceModel(const QStringList &headers, QObject *parent)
     ldapSearchCollections.setAttributes(attrs);
     ldapSearch.setAttributes(headers);
 
-    connect(&ldapSearchCollections,
-            static_cast<void (KLDAP::LdapClientSearch::*)(const KLDAP::LdapResultObject::List &)>(&
-                                                                                                  KLDAP
-                                                                                                  ::
-                                                                                                  LdapClientSearch
-                                                                                                  ::
-                                                                                                  searchData), this,
-            &ResourceModel::slotLDAPCollectionData);
-    connect(&ldapSearch,
-            static_cast<void (KLDAP::LdapClientSearch::*)(const KLDAP::LdapResultObject::List &)>(&
-                                                                                                  KLDAP
-                                                                                                  ::
-                                                                                                  LdapClientSearch
-                                                                                                  ::
-                                                                                                  searchData), this,
-    &ResourceModel::slotLDAPSearchData);
+    connect(&ldapSearchCollections, QOverload<const KLDAP::LdapResultObject::List &>::of(& KLDAP :: LdapClientSearch :: searchData), this, &ResourceModel::slotLDAPCollectionData);
+    connect(&ldapSearch, QOverload<const KLDAP::LdapResultObject::List &>::of(& KLDAP :: LdapClientSearch :: searchData), this, &ResourceModel::slotLDAPSearchData);
 
     ldapSearchCollections.startSearch(QStringLiteral("*"));
 }
@@ -197,7 +183,7 @@ void ResourceModel::startSearch()
     if (searchString.isEmpty()) {
         ldapSearch.startSearch(QStringLiteral("*"));
     } else {
-        ldapSearch.startSearch(QStringLiteral("*") + searchString + QStringLiteral("*"));
+        ldapSearch.startSearch(QLatin1Char('*') + searchString + QLatin1Char('*'));
     }
 }
 
@@ -220,8 +206,8 @@ void ResourceModel::slotLDAPCollectionData(const KLDAP::LdapResultObject::List &
         ldapCollections.insert(item);
 
         // Resources in a collection add this link into ldapCollectionsMap
-        foreach (const QByteArray &member,
-                 result.object.attributes()[QString::fromLatin1("uniqueMember")]) {
+        const auto members = result.object.attributes()[QStringLiteral("uniqueMember")];
+        foreach (const QByteArray &member, members) {
             ldapCollectionsMap.insert(QString::fromLatin1(member), item);
         }
     }
